use spirv_builder::{MetadataPrintout, SpirvBuilder};
use std::env;
use std::fs;
use std::path::{Path, PathBuf};

fn main() -> Result<(), Box<dyn std::error::Error>> {
    let gpu_crate_path = Path::new("../flare-shader/");

    // Compile the shader crate with SpirvBuilder.
    let result = SpirvBuilder::new(gpu_crate_path, "spirv-unknown-vulkan1.2")
        .print_metadata(MetadataPrintout::Full)
        .build()?;

    // Copy the SPIR-V to this crate's output directory
    let shader_path = result.module.unwrap_single();
    let output_path = PathBuf::from(env::var("OUT_DIR")?).join("shader_binary.spv");

    fs::copy(shader_path, &output_path)?;

    println!("Generated shader binary constant at {:?}", output_path);
    Ok(())
}
